﻿Imports System
Imports System.Collections.Generic
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports RFID.Reader
Imports RFID.ReaderComm

Namespace ExampleCodes
    Class ReadSetAntenna
        Shared DEFAULT_READER_IP_ADDRESS As String = "192.168.1.120"
        Shared PORT_NUMBER As UInt16 = 5000
        Shared reader As RFIDReader = Nothing

        Public Shared Sub Main(ByVal args As String())
            Try
                Dim readerIPAddress As String = DEFAULT_READER_IP_ADDRESS
                Dim PortNumber As UInt16 = PORT_NUMBER
                Console.WriteLine("Setting up ReaderComm instance on IP Address " & readerIPAddress)
                reader = New RFIDReader(readerIPAddress, PortNumber)
                Console.WriteLine("Getting Reader Info" & vbLf)
                ReadSequence()
                GetAntennaPowerSettings()
                ReadGapTimes()
            Catch ex As Exception
                Console.WriteLine("Main: " & ex.ToString())
            End Try
        End Sub

        Public Shared Sub ReadSequence()
            Dim antennaSequence As Byte() = New Byte(15) {}
            Dim sequenceLength As Byte = 0
            Dim status As RFIDStatus = ReadSetAntenna.reader.GetReadSequence(antennaSequence, sequenceLength)
            Console.WriteLine(String.Format("Antenna sequence (" & sequenceLength & ")"))

            For idx As Integer = 0 To sequenceLength - 1
                Console.WriteLine(antennaSequence(idx))
            Next

            Console.WriteLine()
            Dim newAntSeq As Byte() = New Byte(4) {}
            newAntSeq(0) = 1
            newAntSeq(1) = 0
            newAntSeq(2) = 3
            newAntSeq(3) = 2
            newAntSeq(4) = 1

            If RFIDStatus.OK = ReadSetAntenna.reader.SetReadSequence(newAntSeq, CByte(newAntSeq.Length)) Then
                Console.WriteLine("Set antenna sequence succeeded")
            Else
                Console.WriteLine("Set antenna sequence failed")
            End If

            Dim validateAntSequence As Byte() = New Byte(15) {}
            Dim validateSequenceLength As Byte = 0
            status = ReadSetAntenna.reader.GetReadSequence(validateAntSequence, validateSequenceLength)
            If validateSequenceLength <> newAntSeq.Length Then Console.WriteLine("Validate antenna sequence failed: length didn't match")

            For idx As Integer = 0 To newAntSeq.Length - 1
                If validateAntSequence(idx) <> newAntSeq(idx) Then Console.WriteLine(String.Format("Validate antenna sequence failed seq[" & idx & "] " & newAntSeq(idx) & " != " & validateAntSequence(idx)))
                ReadSetAntenna.reader.SetReadSequence(antennaSequence, sequenceLength)
            Next
        End Sub

        Public Shared Sub GetAntennaPowerSettings()
            Dim readPower As Double() = New Double(3) {}
            Dim writePower As Double() = New Double(3) {}

            Try
                Dim numberOfAntennas As Integer = 0
                Dim status As RFIDStatus = ReadSetAntenna.reader.GetPowerSetting(numberOfAntennas, readPower, writePower)

                For idx As Integer = 0 To numberOfAntennas - 1

                    If status = RFIDStatus.OK Then
                        Console.WriteLine("Antenna " & idx & " read power " & readPower(idx))
                        Console.WriteLine("Antenna " & idx & " write power " & writePower(idx) & vbLf)
                    Else
                        Console.WriteLine("Get Power Settings for antenna failed. Cause unkown.")
                    End If
                Next

            Catch ex As Exception
                Console.WriteLine("Power: " & ex.Message & Environment.NewLine)
            End Try
        End Sub

        Public Shared Sub ReadGapTimes()
            Dim readTime As UInt16 = 0
            Dim gapTime As UInt16 = 0

            Try

                If ReadSetAntenna.reader.GetReadGapTimes(readTime, gapTime) = RFIDStatus.OK Then
                    Console.WriteLine("Read time: " & readTime)
                    Console.WriteLine("Gap time: " & gapTime)
                Else
                    Console.WriteLine("Error getting read and gap time")
                End If

            Catch ex As Exception
                Console.WriteLine("Get Read & Gap Times: " & ex.Message)
            End Try
        End Sub
    End Class
End Namespace
